import { retryBackoff } from 'backoff-rxjs';

const isServerError = response => response.status >= 500;

const isUnknownError = response => response.status === 0;

const or = (...predicates) => (...args) => {
    return predicates.some(predicate => predicate(...args));
};
const isServerOrUnknownError = response => {
    return or(isServerError, isUnknownError)(response);
};

class RetryHandler {
    constructor({ initialInterval, maxInterval, maxRetries, shouldRetry }) {
        this._initialInterval = initialInterval;
        this._maxInterval = maxInterval;
        this._maxRetries = maxRetries;
        this._shouldRetry = shouldRetry;
    }
    handle({ request, next }) {
        return next({ request }).pipe(retryBackoff({
            initialInterval: this._initialInterval,
            maxInterval: this._maxInterval,
            maxRetries: this._maxRetries,
            shouldRetry: this._shouldRetry
        }));
    }
}

/**
 * @param shouldHandleRequest
 * @param initialInterval defaults to 200ms
 * @param maxInterval defaults to 1min
 * @param maxRetries defaults to 10
 * @param shouldRetry defaults to server error: 5xx
 */
function createRetryPlugin({ shouldHandleRequest = () => true, initialInterval = 200, maxInterval = 60000, // 1 min
maxRetries = 10, shouldRetry = isServerOrUnknownError } = {}) {
    return {
        shouldHandleRequest,
        handler: new RetryHandler({
            initialInterval,
            maxInterval,
            maxRetries,
            shouldRetry
        })
    };
}

/**
 * Generated bundle index. Do not edit.
 */

export { createRetryPlugin, RetryHandler as ɵa };
//# sourceMappingURL=http-ext-plugin-retry.js.map
